jaclearn.imageaug.shape
=======================

.. automodule:: jaclearn.imageaug.shape

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      horizontal_flip_augment
      random_crop
      random_crop_and_resize
      random_crop_random_shape
      random_size_crop
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: horizontal_flip_augment

.. autofunction:: random_crop

.. autofunction:: random_crop_and_resize

.. autofunction:: random_crop_random_shape

.. autofunction:: random_size_crop


